@@ -14,7 +14,7 @@
  * ========================================================================
  */
 
-void add_ui_rngs()
+void add_ui_rngs(void)
 {
 
   //int i; 
